==> tencentcloud-sdk-java-3.1.920-sources.jar: com/tencentcloudapi/essbasic/v20210526/models/ChannelDescribeFlowComponentsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.essbasic.v20210526.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ChannelDescribeFlowComponentsResponse extends AbstractModel {

    /**
    * 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
    */
    @SerializedName("RecipientComponentInfos")
    @Expose
    private RecipientComponentInfo [] RecipientComponentInfos;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 合同填写控件信息列表，填写控件会按照参与方角色进行分类。 
     * @return RecipientComponentInfos 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
     */
    public RecipientComponentInfo [] getRecipientComponentInfos() {
        return this.RecipientComponentInfos;
    }

    /**
     * Set 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
     * @param RecipientComponentInfos 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
     */
    public void setRecipientComponentInfos(RecipientComponentInfo [] RecipientComponentInfos) {
        this.RecipientComponentInfos = RecipientComponentInfos;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public ChannelDescribeFlowComponentsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public ChannelDescribeFlowComponentsResponse(ChannelDescribeFlowComponentsResponse source) {
        if (source.RecipientComponentInfos != null) {
            this.RecipientComponentInfos = new RecipientComponentInfo[source.RecipientComponentInfos.length];
            for (int i = 0; i < source.RecipientComponentInfos.length; i++) {
                this.RecipientComponentInfos[i] = new RecipientComponentInfo(source.RecipientComponentInfos[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "RecipientComponentInfos.", this.RecipientComponentInfos);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.1000-sources.jar: com/tencentcloudapi/essbasic/v20210526/models/ChannelDescribeFlowComponentsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.essbasic.v20210526.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ChannelDescribeFlowComponentsResponse extends AbstractModel {

    /**
    * 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
    */
    @SerializedName("RecipientComponentInfos")
    @Expose
    private RecipientComponentInfo [] RecipientComponentInfos;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 合同填写控件信息列表，填写控件会按照参与方角色进行分类。 
     * @return RecipientComponentInfos 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
     */
    public RecipientComponentInfo [] getRecipientComponentInfos() {
        return this.RecipientComponentInfos;
    }

    /**
     * Set 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
     * @param RecipientComponentInfos 合同填写控件信息列表，填写控件会按照参与方角色进行分类。
     */
    public void setRecipientComponentInfos(RecipientComponentInfo [] RecipientComponentInfos) {
        this.RecipientComponentInfos = RecipientComponentInfos;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public ChannelDescribeFlowComponentsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public ChannelDescribeFlowComponentsResponse(ChannelDescribeFlowComponentsResponse source) {
        if (source.RecipientComponentInfos != null) {
            this.RecipientComponentInfos = new RecipientComponentInfo[source.RecipientComponentInfos.length];
            for (int i = 0; i < source.RecipientComponentInfos.length; i++) {
                this.RecipientComponentInfos[i] = new RecipientComponentInfo(source.RecipientComponentInfos[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "RecipientComponentInfos.", this.RecipientComponentInfos);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
